@@ -1,5 +1,5 @@
 import torch
-from aimped.nlp.tokenizer import sentence_tokenizer, word_tokenizer
+from aimped.nlp.tokenizer import SentenceTokenizer, WordTokenizer
 from transformers import AutoTokenizer, AutoModelForTokenClassification
 from aimped.nlp.pipeline import Pipeline
 
@@ -12,15 +12,15 @@ device = torch.device("cuda" if torch.cuda.is_available() else "cpu")
 
 # load data
 text = open("data.txt", "r").read()
-sentences = sentence_tokenizer(text, "english")
-sents_tokens_list = word_tokenizer(sentences)
+sentences = SentenceTokenizer(text, "english")
+sents_tokens_list = WordTokenizer(sentences)
 white_label_list = ['PATIENT', 'ORGANIZATION', 'SSN', 'SEX', 'DOCTOR', 'HOSPITAL', 'AGE', 'MEDICALRECORD', 'ZIP',
                     'STREET', 'EMAIL', 'DATE', 'ID', 'CITY', 'COUNTRY', 'PROFESSION']
 # print(sents_tokens_list)
 pipe = Pipeline(model=model, tokenizer=tokenizer, device='cpu')
-tokens, preds, probs, begins, ends = pipe.ner_results(text=text,
-                                                      sents_tokens_list=sents_tokens_list,
-                                                      sentences=sentences)
+tokens, preds, probs, begins, ends = pipe.ner_result(text=text,
+                                                     sents_tokens_list=sents_tokens_list,
+                                                     sentences=sentences)
 print("tokens: ", tokens)
 print("preds: ", preds)
 print("probs:", probs)
